@@ -298,7 +298,6 @@ html_cursor_up (HTMLCursor *cursor,
 	gint prev_x, prev_y;
 	gint x, y;
 	gint target_x;
-	gint orig_y;
 	gboolean new_line;
 
 	gtk_html_im_reset (engine->widget);
@@ -330,8 +329,6 @@ html_cursor_up (HTMLCursor *cursor,
 
 	target_x = cursor->target_x;
 
-	orig_y = y;
-
 	new_line = FALSE;
 
 	while (1) {
@@ -416,7 +413,6 @@ html_cursor_down (HTMLCursor *cursor,
 	gint prev_x, prev_y;
 	gint x, y;
 	gint target_x;
-	gint orig_y;
 	gboolean new_line;
 
 	gtk_html_im_reset (engine->widget);
@@ -448,8 +444,6 @@ html_cursor_down (HTMLCursor *cursor,
 
 	target_x = cursor->target_x;
 
-	orig_y = y;
-
 	new_line = FALSE;
 
 	while (1) {
