@@ -394,9 +394,11 @@ draw_border (HTMLPainter *painter,
 
 	switch (style) {
 	case HTML_BORDER_SOLID:
+		/* do not draw peripheral border *
 		col1 = bg;
 		col2 = bg;
-		break;
+		break; */
+		return;
 	case HTML_BORDER_OUTSET:
 		col1 = &light;
 		col2 = &dark;
@@ -502,16 +504,12 @@ static void
 draw_pixmap (HTMLPainter *painter, GdkPixbuf *pixbuf, gint x, gint y, gint scale_width, gint scale_height, const GdkColor *color)
 {
 	HTMLPrinter *printer;
-	gint width, height;
 	double print_x, print_y;
 	double print_scale_width, print_scale_height;
 
 	printer = HTML_PRINTER (painter);
 	g_return_if_fail (printer->context != NULL);
 
-	width = gdk_pixbuf_get_width (pixbuf);
-	height = gdk_pixbuf_get_height (pixbuf);
-
 	html_printer_coordinates_to_gnome_print (printer, x, y, &print_x, &print_y);
 
 	print_scale_width  = SCALE_ENGINE_TO_GNOME_PRINT (scale_width);
@@ -599,7 +597,7 @@ draw_lines (HTMLPrinter *printer, double x, double y, double width, PangoAnalysi
 }
 
 static gint
-draw_glyphs (HTMLPainter *painter, gint x, gint y, PangoItem *item, PangoGlyphString *glyphs)
+draw_glyphs (HTMLPainter *painter, gint x, gint y, PangoItem *item, PangoGlyphString *glyphs, GdkColor *fg, GdkColor *bg)
 {
 	HTMLPrinter *printer;
 	gdouble print_x, print_y;
@@ -648,7 +646,7 @@ draw_glyphs (HTMLPainter *painter, gint x, gint y, PangoItem *item, PangoGlyphSt
 	gnome_print_grestore (printer->context);
 	
 	
-	return html_painter_pango_to_engine (painter, log_rect.width);
+	return log_rect.width;
 }
 
 static void
